@@ -4,8 +4,24 @@
 /********************************* os *********************************/
 /**********************************************************************/
 
-/* $Id: os.h,v 1.10 1992/07/10 16:58:29 beebe Exp beebe $
+/* $Id: os.h,v 1.1 1992/11/07 23:24:26 beebe Exp beebe $
  * $Log: os.h,v $
+ *
+ * Revision 1.15  1992/10/11  01:51:52  beebe
+ * Correct error in VOID_ARG definition in non Standard C environment.
+ *
+ * Revision 1.14  1992/10/10  13:50:23  beebe
+ * Add fileno() definition for Turbo C 3.0 or later.
+ *
+ * Revision 1.13  1992/10/09  23:58:02  beebe
+ * Add definitions of stdprn and stdaux for Turbo C 3.0 or later.
+ *
+ * Revision 1.12  1992/10/08  14:45:19  beebe
+ * Update for NeXT.  Use only __NeXT__ preprocessor symbol.
+ *
+ * Revision 1.11  1992/10/08  01:42:01  beebe
+ * Update for C++.
+ *
  * Revision 1.10  1992/07/10  16:58:29  beebe
  * Remove support for Lattice C.
  * Add more HAVE_xxx preprocessor settings.
@@ -37,8 +53,8 @@
  *
  */
 
-#ifndef OS_H_DEFINED__ /* file ignored if included more than once */
-#define OS_H_DEFINED__
+#ifndef OS_H_DEFINED_ /* file ignored if included more than once */
+#define OS_H_DEFINED_
 
 /***********************************************************************
 This file sets the operating system and compiler flags, automatically
@@ -184,75 +200,11 @@ header files and predefined types are available.
 #define UNIX_BSD		0
 #endif /* UNIX_BSD */
 
-/***********************************************************************
-The VAX VMS compiler complains about undefined macros when the
-/STANDARD=PORTABLE compiler switch is used; to avoid masking other
-legitimate problems, we define all otherwise unused, but referenced,
-preprocessor symbols here.
-***********************************************************************/
-#if VMS
-#define AIX			0
-#define HAVE_CLOCK_T		0
-#define HAVE_CONST_TYPE		0
-#define HAVE_ERRNO_H		0
-#define HAVE_FPOS_T		0
-#define HAVE_GETCWD		0
-#define HAVE_GETCWD_DCL		0
-#define HAVE_GETHOSTNAME_DCL	0
-#define HAVE_GETWD		0
-#define HAVE_GETWD_DCL		0
-#define HAVE_MATH_H		1
-#define HAVE_PARAM_H		0
-#define HAVE_PROTOTYPES		0
-#define HAVE_PWD_H		0
-#define HAVE_SIZE_T		0
-#define HAVE_STDDEF_H		0
-#define HAVE_STDLIB_H		0
-#define HAVE_STRFTIME		0
-#define HAVE_STRFTIME_DCL	0
-#define HAVE_SYS_DIR		0
-#define HAVE_TIME_T		0
-#define HAVE_TZNAME		0
-#define HAVE_TZNAME_DCL		0
-#define HAVE_VOIDP		0
-#define HAVE_VOLATILE_TYPE	0
-#define IBM_PC_MICROSOFT	0
-#define IBM_PC_TURBO		0
-#define _INCLUDE_POSIX_SOURCE	0
-#define KCC_20			0
-#define MSDOS			0
-#define NeXT			0
-#define PCC_20			0
-#define UNIXPC			0
-#define UNIX_ATT		0
-#define UNIX_BSD		0
-#define _AIX			0
-#define _AIX370			0
-#define _IBMR2			0
-#define __ACC__			0
-#define __COMPILER_KCC__	0
-#define __GNUC__		0
-#define __LCC__			0
-#define __NeXT__		0
-#define __TURBOC__		0
-#define __hppa			0
-#define __hpux			0
-#define __sgi			0
-#define __sgi__			0
-#define _hpux			0
-#define ardent			0
-#define hp300			0
-#define hpux			0
-#define mips			0
-#define ps2			0
-#define sgi			0
-#define sun			0
-#define sun386			0
-#define ultrix			0
-#define unix			0
-#define unixpc			0
-#define usg			0
-#endif /* VMS */
+#ifdef c_plusplus
+#ifndef __cplusplus
+#define __cplusplus		1	/* we only use this new name */
+#endif /* __cplusplus */
+#endif /* c_plusplus */
 
 /***********************************************************************
 We start by assuming that most implementations will have certain basic
@@ -302,9 +254,9 @@ can all be overridden at compile time.
 #define HAVE_FILE_H		1
 #endif /* HAVE_FILE_H */
 
-#ifndef HAVE_GETWD
-#define HAVE_GETWD		1
-#endif /* HAVE_GETWD */
+#ifndef HAVE_LIMITS_H
+#define HAVE_LIMITS_H		1
+#endif /* HAVE_LIMITS_H */
 
 #ifndef HAVE_MATH_H
 #define HAVE_MATH_H		1
@@ -330,10 +282,72 @@ can all be overridden at compile time.
 #define HAVE_TYPES_H		1
 #endif /* HAVE_TYPES_H */
 
+/***********************************************************************
+A few getxxx() library functions are often not declared in system
+header files.  Start by assuming they are properly declared.
+***********************************************************************/
+
+#ifndef HAVE_GETWD
+#define HAVE_GETWD		0	/* avoid: not a Posix function */
+#endif /* HAVE_GETWD */
+
+#ifndef HAVE_GETWD_DCL
+#define HAVE_GETWD_DCL		0
+#endif /* HAVE_GETWD_DCL */
+
+#ifndef HAVE_GETCWD
+#define HAVE_GETCWD		1
+#endif /* HAVE_GETCWD */
+
+#ifndef HAVE_GETCWD_DCL
+#define HAVE_GETCWD_DCL		1
+#endif /* HAVE_GETCWD_DCL */
+
+
+#ifndef HAVE_GETHOSTNAME
+#define HAVE_GETHOSTNAME	1	/* most systems have it, but */
+#endif /* HAVE_GETHOSTNAME */
+
+#ifndef HAVE_GETHOSTNAME_DCL
+#define HAVE_GETHOSTNAME_DCL	0	/* lack a function prototype */
+#endif /* HAVE_GETHOSTNAME_DCL */
+
+
+#ifndef HAVE_GETLOGIN
+#define HAVE_GETLOGIN		1
+#endif /* HAVE_GETLOGIN */
+
+#ifndef HAVE_GETLOGIN_DCL
 #define HAVE_GETLOGIN_DCL	1
+#endif /* HAVE_GETLOGIN_DCL */
+
+
+#ifndef HAVE_GETPWNAM
+#define HAVE_GETPWNAM		1
+#endif /* HAVE_GETPWNAM */
+
+#ifndef HAVE_GETPWNAM_DCL
 #define HAVE_GETPWNAM_DCL	1
+#endif /* HAVE_GETPWNAM_DCL */
+
+
+#ifndef HAVE_GETPWUID
+#define HAVE_GETPWUID		1
+#endif /* HAVE_GETPWUID */
+
+#ifndef HAVE_GETPWUID_DCL
 #define HAVE_GETPWUID_DCL	1
+#endif /* HAVE_GETPWUID_DCL */
+
+
+#ifndef HAVE_GETUID
+#define HAVE_GETUID		1
+#endif /* HAVE_GETUID */
+
+#ifndef HAVE_GETUID_DCL
 #define HAVE_GETUID_DCL		1
+#endif /* HAVE_GETUID_DCL */
+
 
 /***********************************************************************
 Now check for the definition of certain predefined symbols to see if
@@ -348,6 +362,96 @@ SAS/Lattice C compiler does.  Compile-time definition of OS_VMCMS will
 therefore be necessary.
 ***********************************************************************/
 
+#if    VMS
+/***********************************************************************
+The VAX VMS compiler complains about undefined macros when the
+/STANDARD=PORTABLE compiler switch is used.  To avoid masking other
+legitimate problems, we define ALL referenced preprocessor symbols here.
+***********************************************************************/
+
+#define AIX			0
+#define BSD			0
+#define HAVE_CLOCK_T		1
+#define HAVE_CONST_TYPE		0
+#define HAVE_ERRNO_H		0
+#define HAVE_FPOS_T		1
+#define HAVE_GETCWD		1
+#define HAVE_GETCWD_DCL		1
+#define HAVE_GETHOSTNAME	0
+#define HAVE_GETHOSTNAME_DCL	0
+#define HAVE_GETWD		0
+#define HAVE_GETWD_DCL		0
+#define HAVE_LIMITS_H		1
+#define HAVE_MATH_H		1
+#define HAVE_MEMXXX_DCL		1	/* string.h has memxxx() declarations */
+#define HAVE_PARAM_H		0
+#define HAVE_PROTOTYPES		0
+#define HAVE_PWD_H		0
+#define HAVE_SIZE_T		0
+#define HAVE_STDDEF_H		0
+#define HAVE_STDLIB_H		0
+#define HAVE_STRFTIME		0
+#define HAVE_STRFTIME_DCL	0
+#define HAVE_SYS_DIR		0
+#define HAVE_TIME_T		0
+#define HAVE_TM_ZONE		0
+#define HAVE_TZNAME		0
+#define HAVE_TZNAME_DCL		0
+#define HAVE_VOIDP		0
+#define HAVE_VOLATILE_TYPE	0
+#define IBM_PC_MICROSOFT	0
+#define IBM_PC_TURBO		0
+#define KCC_20			0
+#define MSDOS			0
+#define PCC_20			0
+#define STDC			0
+#define UNIXPC			0
+#define UNIX_ATT		0
+#define UNIX_BSD		0
+#define _AIX			0
+#define _AIX370			0
+#define _IBMR2			0
+#define _HPUX_SOURCE		0
+#define _POSIX_SOURCE		0
+#define __ACC__			0
+#define __CC__			0
+#define __COMPILER_KCC__	0
+#define __GNUC__		0
+#define __GNUG__		0
+#define __LCC__			0
+#define __NeXT__		0
+#define __STDC__		0
+#define __SUNCC__		0
+#define __TURBOC__		0
+#define __convex__		0
+#define __cplusplus		0
+#define __hppa			0
+#define __hpux			0
+#define __sgi			0
+#define __sgi__			0
+#define __unix			0
+#define ardent			0
+#define c_plusplus		0
+#define hp300			0
+#define hpux			0
+#define mips			0
+#define ps2			0
+#define sgi			0
+#define sun			0
+#define sun386			0
+#define ultrix			0
+#define unix			0
+#define unixpc			0
+#define usg			0
+
+#ifdef OS_VAXVMS
+#undef OS_VAXVMS
+#endif /* OS_VAXVMS */
+
+#define OS_VAXVMS		1
+#define STDC			1
+#endif /* VMS */
+
 #if    (unix || __unix)		/* (all?) UNIX systems define one of these */
 
 #ifdef OS_UNIX
@@ -355,6 +459,7 @@ therefore be necessary.
 #endif /* OS_UNIX */
 
 #define OS_UNIX			1
+
 #endif /* (unix || __unix) */
 
 #if    _AIX
@@ -373,12 +478,23 @@ RS/6000:	_AIX	_IBMR2
 #undef OS_UNIX
 #endif /* OS_UNIX */
 
-#ifndef _IBMR2
+#if (_AIX370 || ps2)
+#define HAVE_MEMXXX_DCL		1
 #undef HAVE_FPOS_T		/* fpos_t is missing from <sys/types.h> */
 #undef HAVE_GETLOGIN_DCL
 #undef HAVE_GETPWNAM_DCL
 #undef HAVE_GETWD_DCL
-#endif /* _IBMR2 */
+#if __cplusplus
+#define HAVE_FPOS_T		1
+#define HAVE_GETLOGIN_DCL	1
+#define HAVE_GETLOGIN		1
+#define HAVE_GETPWNAM_DCL	1
+#define HAVE_GETPWNAM		1
+#define HAVE_GETWD_DCL		1
+#undef HAVE_GETWD
+#define HAVE_GETWD		1
+#endif /* __cplusplus */
+#endif /*  (_AIX370 || ps2) */
 
 #define OS_UNIX			1
 #define STDC			1
@@ -427,6 +543,20 @@ pre-Standard C compilers */
 
 #define IBM_PC_TURBO		1
 #define STDC			1
+
+#if (__TURBOC__ >= 0x0400)
+/* tcc 3.0 does not define stdaux or stdprn in the __STDC__ environment,
+but we need them, and fileno() too */
+#define fileno(f)       ((f)->fd)
+#if __cplusplus
+#define stdaux		__getStream(3)
+#define stdprn		__getStream(4)
+#else /* NOT __cplusplus */
+#define stdaux		(&_streams[3])
+#define stdprn		(&_streams[4])
+#endif /* __cplusplus */
+
+#endif /* (__TURBOC__ >= 0x400) */
 #endif /* __TURBOC__ */
 
 #if    __COMPILER_KCC__
@@ -479,21 +609,6 @@ pre-Standard C compilers */
 #endif /* (KCC_20 || PCC_20) */
 #endif /* OS_TOPS20 */
 
-#if    VMS
-#undef HAVE_PARAM_H
-#undef HAVE_CLOCK_T
-
-#define HAVE_PARAM_H		0
-#define HAVE_CLOCK_T		1
-
-#ifdef OS_VAXVMS
-#undef OS_VAXVMS
-#endif /* OS_VAXVMS */
-
-#define OS_VAXVMS		1
-#define STDC			1
-#endif /* VMS */
-
 #if    __ACC__			/* Sun 4 SunOS 4.1.1 semi-Standard C compiler */
 #define sun			1	/* doesn't define, but we need it */
 #define STDC			1
@@ -504,8 +619,10 @@ pre-Standard C compilers */
 #if    ardent				/* Ardent Titan (Stardent 1520) UNIX */
 #undef HAVE_CLOCK_T			/* (System V + BSD extensions) */
 #undef HAVE_FPOS_T
+#undef HAVE_GETCWD_DCL
 #undef HAVE_GETLOGIN_DCL
 #undef HAVE_GETWD
+#undef HAVE_GETWD_DCL
 #undef HAVE_PROTOTYPES
 #undef HAVE_VOIDP
 
@@ -513,6 +630,11 @@ pre-Standard C compilers */
 					/* don't use it, so we must not */
 					/* either to avoid declaration  */
 					/* conflicts */
+#define HAVE_GETCWD		1
+#define HAVE_GETCWD_DCL		0	/* missing from include files */
+#define HAVE_GETLOGIN		1
+#define HAVE_GETLOGIN_DCL	0	/* missing from include files */
+#define HAVE_MEMXXX_DCL		1
 #define HAVE_PROTOTYPES		1
 #define HAVE_SIZE_T		1
 #define HAVE_TIME_T		1
@@ -523,11 +645,21 @@ pre-Standard C compilers */
 #define UNIX_ATT		1
 #endif /* ardent */
 
+#if BSD					/* this works for BSD 4.3 on HP 370 */
+#undef HAVE_FPOS_T
+#undef HAVE_GETWD
+#undef HAVE_GETWD_DCL
+#undef UNIX_BSD
+#define HAVE_GETWD		1
+#define HAVE_GETWD_DCL		1
+#define UNIX_BSD		1
+#endif
+
 #if __convex__
 #define STDC			1
 #endif /* __convex__ */
 
-#if __GNUC__
+#if (__GNUC__ || __cplusplus)
 #undef HAVE_CONST_TYPE
 #undef HAVE_PROTOTYPES
 #undef HAVE_VOIDP
@@ -537,28 +669,38 @@ pre-Standard C compilers */
 #define HAVE_PROTOTYPES		1
 #define HAVE_VOIDP		1
 #define HAVE_VOLATILE_TYPE	1
-#endif /* __GNUC__ */
-
-#if hp300 && __GNUC__			/* HP 3xx with 4.3 BSD */
-#define HAVE_SPRINTF_DCL	1
-#endif /* hp300 && __GNUC__ */
-
-#if    __hppa && _INCLUDE_POSIX_SOURCE
 #define STDC			1
-#define HAVE_GETCWD		1
-#define HAVE_GETCWD_DCL		1
+#endif /* (__GNUC__ || __cplusplus) */
+
+#if    __hppa && _POSIX_SOURCE
+#define STDC			1
 #define HAVE_STDDEF_H		1
 #define HAVE_STDLIB_H		1
-#endif /* __hppa && _INCLUDE_POSIX_SOURCE */
+#endif /* __hppa && _POSIX_SOURCE */
 
-#if    hpux	/* Hewlett-Packard UNIX (System V + BSD extensions) */
+#if    __hppa && _HPUX_SOURCE
+#define STDC			1
+#define HAVE_STDDEF_H		1
+#define HAVE_STDLIB_H		1
+#undef HAVE_GETHOSTNAME
+#define HAVE_GETHOSTNAME	1
+#undef HAVE_GETHOSTNAME_DCL
+#define HAVE_GETHOSTNAME_DCL	1
+#endif /* __hppa && _HPUX_SOURCE */
+
+#if    (hpux || __hpux)	/* Hewlett-Packard UNIX (System V + BSD extensions) */
 #undef HAVE_GETWD
 #undef HAVE_TZNAME
 #undef UNIX_ATT
 
 #define HAVE_TZNAME             1
+
+#ifdef __STDC__
+#define STDC			1
+#endif /* __STDC__ */
+
 #define UNIX_ATT		1
-#endif /* hpux */
+#endif /* (hpux || __hpux) */
 
 #if    __LCC__		/* AT&T / Princeton retargetable Standard C compiler: */
 			/* lcc has code generators for several architectures, */
@@ -568,7 +710,7 @@ pre-Standard C compilers */
 #define HAVE_STDLIB_H		1
 #endif /* __LCC__ */
 
-#if mips && !(ardent || sgi || ultrix)	/* MIPS UNIX (System V.3 and BSD 4.3) */
+#if mips && !(ardent || __sgi || ultrix)/* MIPS UNIX (System V.3 and BSD 4.3) */
 
 #undef HAVE_FPOS_T		/* fpos_t is missing from <sys/types.h> */
 #undef HAVE_CLOCK_T
@@ -576,13 +718,14 @@ pre-Standard C compilers */
 #undef HAVE_GETPWNAM_DCL
 #undef HAVE_GETUID_DCL
 
+#define HAVE_MEMXXX_DCL		1
 #define HAVE_TM_ZONE		1	/* time.h struct tm has tm_zone */
 					/* in -systype bsd43 environment */
 #undef UNIX_BSD
 #define UNIX_BSD		1
-#endif /* mips && !(ardent || sgi || ultrix) */
+#endif /* mips && !(ardent || __sgi || ultrix) */
 
-#if    NeXT
+#if    __NeXT__
 /* NeXT systems use the GNU C compiler and MACH (4.3BSD system call
 compatible).  The compiler predefines __MACH__, mc68000, NeXT,
 __STDC__, and unix, and has Standard C-conformant library and header
@@ -590,13 +733,20 @@ files. */
 #define STDC			1
 #undef UNIX_BSD
 #define UNIX_BSD		1
-#endif /* NeXT */
+#undef HAVE_GETUID_DCL
+#undef HAVE_GETWD
+#undef HAVE_GETWD_DCL
+#define HAVE_GETWD		1
+#define HAVE_GETWD_DCL		1
+#undef HAVE_GETCWD
+#undef HAVE_GETCWD_DCL
+#endif /* __NeXT__ */
 
-#if    sgi				/* Silicon Graphics UNIX System V.x */
+#if    (sgi || __sgi)			/* Silicon Graphics UNIX System V.x */
 
 #undef UNIX_ATT
 #define UNIX_ATT		1
-#endif /* sgi */
+#endif /* (sgi || __sgi) */
 
 #if __sgi__ && __GNUC__
 /* GNU C 1.39 is missing these symbols that cc defines, and we need them */
@@ -609,43 +759,61 @@ files. */
 
 #if    __sgi			/* Silicon Graphics Iris Indigo IRIX 4.0.1*/
 #define STDC			1
+#define HAVE_MEMXXX_DCL		1
 #define HAVE_SSCANF_FUNCTION	1
-#define HAVE_SPRINTF_DCL	1
 #define HAVE_OPEN_DCL		1
-#define HAVE_CREAT_DCL		1
-#define HAVE_CLOSE_DCL		1
 #define HAVE_STDDEF_H		1
 #define HAVE_STDLIB_H		1
 #endif /* __sgi */
 
+#if    __SUNCC__
+#define sun	1
+#endif /* __SUNCC__ */
+
 #if    sun	/* Sun Microsystems UNIX OS 3.x and 4.x (4.2BSD) */
 #undef HAVE_FPOS_T		/* fpos_t is missing from <sys/types.h> */
-
-#if    !__ACC__
+#undef HAVE_GETCWD_DCL
 #undef HAVE_GETLOGIN_DCL
 #undef HAVE_GETUID_DCL
-#endif /* !__ACC__ */
+
+#if	__ACC__
+#define HAVE_MEMXXX_DCL		1
+#endif /* __ACC__ */
+
+#define HAVE_GETLOGIN_DCL	1
+#define HAVE_GETUID_DCL		1
+
+#if    __GNUC__
+#undef HAVE_GETLOGIN_DCL
+#undef HAVE_GETUID_DCL
+#endif /* __GNUC__ */
+
+#if    __SUNCC__
+#undef HAVE_GETWD
+#undef HAVE_GETWD_DCL
+#define HAVE_GETWD	1
+#define HAVE_GETWD_DCL	1
+#endif /* __SUNCC__ */
 
 #if    sun386				/* Sun 386i */
 #undef HAVE_CLOCK_T
 #undef HAVE_GETLOGIN_DCL
 
 #define HAVE_SSCANF_FUNCTION	1	/* true for all versions */
-#define HAVE_SPRINTF_DCL	1	/* true at SunOS 4.0 or later */
 #else					/* Sun 3 or 4 */
 #define HAVE_SSCANF_FUNCTION	1	/* true for all versions */
-#define HAVE_SPRINTF_DCL	1	/* true at SunOS 4.0 or later */
 #define HAVE_OPEN_DCL		1	/* true at SunOS 4.0 or later */
 					/* defined in sys/fcntlcom.h */
-#define HAVE_CREAT_DCL		1	/* true at SunOS 4.0 or later */
-					/* defined in sys/fcntlcom.h */
 #define HAVE_STDDEF_H		1	/* true at SunOS 4.1 or later, even */
 					/* though cc is not yet Standard C */
 #define HAVE_STDLIB_H		1	/* true at SunOS 4.1 or later, even */
 					/* though cc is not yet Standard C */
 #endif /* sun386 */
 
-#define HAVE_STRDUP_DCL		1
+#if __cplusplus
+#undef HAVE_OPEN_DCL
+#endif /* __cplusplus */
+
 #define HAVE_TM_ZONE		1	/* time.h struct tm has tm_zone */
 
 #undef UNIX_BSD
@@ -653,8 +821,14 @@ files. */
 #endif /* sun */
 
 #if    ultrix	/* DEC version of 4.2BSD UNIX */
+#define HAVE_MEMXXX_DCL		1
 #define HAVE_OPEN_DCL		1
 #define HAVE_TM_ZONE		1	/* time.h struct tm has tm_zone */
+#undef HAVE_GETUID_DCL
+
+#if   __GNUG__
+#define HAVE_GETUID_DCL		1
+#endif
 
 #if    __LCC__
 #undef HAVE_TM_ZONE
@@ -702,7 +876,12 @@ flags that must be changed.
 #undef HAVE_VOLATILE_TYPE
 
 #define HAVE_CONST_TYPE		1
-#define HAVE_FPOS_T		1
+
+#if sun
+#define HAVE_FPOS_T		__ACC__
+			/* acc has it, but cc, gcc, and g++ stdio.h lack it */
+#endif /* sun */
+
 #define HAVE_PROTOTYPES		1
 #define HAVE_SIZE_T		1
 #define HAVE_TIME_T		1
@@ -718,6 +897,7 @@ flags that must be changed.
 #undef HAVE_GETWD_DCL
 #undef HAVE_FILE_H
 #undef HAVE_PARAM_H
+#define HAVE_MEMXXX_DCL		1
 #endif /* OS_PCDOS */
 
 #if    OS_PRIMOS
@@ -879,19 +1059,21 @@ The limit on file name lengths is similarly non-standard.
 Name		Definition	System
 --------	-------------	------------------------------------------
 FNMAX		<stdio.h>	PCC-20
-MAXPATH		<dir.h>		Turbo C 2.0
-_MAX_PATH	<stdlib.h>	Microsoft C 5.0
+MAXPATH		<dir.h>		Turbo C 2.0, C and C++ 3.0, and TopSpeed C
+_MAX_PATH	<stdlib.h>	Microsoft C 5.0, 6.0, 7.0 and TopSpeed C
 MAXPATHLEN	<sys/param.h>	Sun OS (4.2BSD), 4.3BSD, Gould UTX/32,
 				HPUX, KCC-20, AIX (RT, RS, PS/2, 370),
 				HP/Apollo DomainOS
 PATH_MAX	<stdio.h>	SYS V (Silicon Graphics)
 PATH_MAX	<limits.h>	POSIX
-FILENAME_MAX	<stdio.h>	Intel RMX, NeXT MACH
+FILENAME_MAX	<stdio.h>	Intel RMX, NeXT Mach, Turbo C/C++ 3.0
 --------	-------------	------------------------------------------
 
-We already have included <sys/param.h> or <limits.h>, but we don't want
-to include <stdio.h>.  If we cannot find preset values, we set values
-based on experience; this parameter is less critical than OPENMAX.
+We already have included <sys/param.h>, <limits.h>, and <stdio.h>.  If
+we cannot find preset values, we set values based on experience; this
+parameter is less critical than OPENMAX.  MAXPATHLEN should also be
+long enough to hold a file search path from an environment variable;
+on systems with small MAXPATHLEN values, this may be a problem.
 ***********************************************************************/
 
 #ifndef MAXPATHLEN
@@ -930,7 +1112,8 @@ based on experience; this parameter is less critical than OPENMAX.
 #endif /* OS_ATARI */
 
 #if    OS_PCDOS
-#define MAXPATHLEN		80
+#define MAXPATHLEN		260	/* used to be 80, but recent DOS */
+					/* C compilers have 260 */
 #endif /* OS_PCDOS */
 
 #if    OS_PRIMOS
@@ -1029,4 +1212,10 @@ is a literal dollar sign.
 #define RCSID(s)
 #endif /* OS_UNIX */
 
-#endif /* OS_H_DEFINED__ */
+#if STDC
+#define VOID_ARG	void
+#else
+#define VOID_ARG
+#endif /* STDC */
+
+#endif /* OS_H_DEFINED_ */
