@@ -4,6 +4,8 @@
 /****************************** vmswild *******************************/
 /**********************************************************************/
 
+#include "os.h"
+
 #if 0			/* BEGIN COMMENT SECTION */
 
 /* Compile with TEST defined to create a stand-alone test program */
@@ -86,14 +88,14 @@
 **   int argc;
 **   char **argv;
 ** {
-**   /* local variables */
-** #ifdef VMS     /* Or whatever the Standard C-conforming word will be */
+**   !* local variables *!
+** #ifdef VMS     !* Or whatever the Standard C-conforming word will be *!
 ** 	extern char **cmd_lin();
 **
 ** 	argv = cmd_lin( "", &argc, argv );
-** 	/* The first argument provides misc. options (not currenly used). */
-** #endif /* VMS */
-** 	/* your routine */
+** 	!* The first argument provides misc. options (not currenly used). *!
+** #endif !* VMS *!
+** 	!* your routine *!
 ** }
 **
 ** $ run grep
@@ -199,9 +201,19 @@ static char version[] = /* (Not currently) printed inside "debug" option. */
   "cmd_lin() V2.0, Copyright (C) 1988 Eric Tye McQueen (3-Mar).";
 #endif /* 0 */
 
-static char rcsid[] = "$Id: vmswild.c,v 1.4 1992/07/10 18:03:46 beebe Exp beebe $";
+static char rcsid[] = "$Id: vmswild.c,v 1.6 1992/11/15 16:59:38 beebe Exp beebe $";
 
 /* $Log: vmswild.c,v $
+ * Revision 1.6  1992/11/15  16:59:38  beebe
+ * Correct some function declarations converted incompletely during
+ * the C++ conversion.  Add some more typecasts, using NULL instead of 0.
+ * Remove static attribute from cmd_line() declaration.
+ *
+ * Revision 1.5  1992/10/08  01:42:01  beebe
+ * Update for C++.
+ * Modify some comments to avoid confusing preprocessors that
+ * parse text lines between #if 0 ... #endif.
+ *
  * Revision 1.4  1992/07/10  18:03:46  beebe
  * Add some typecasts.
  *
@@ -222,10 +234,18 @@ static char rcsid[] = "$Id: vmswild.c,v 1.4 1992/07/10 18:03:46 beebe Exp beebe
 /* Dummy version of cmd_lin() for non VAX C (nonVMS) systems: */
 
 char **
+#if STDC
+cmd_lin(
+char	*opt0,				/* Options specified in `main()' */
+int	*ainpc,				/* &main\argc (input and output) */
+char	**inpv				/* main\argv (input) */
+)
+#else /* NOT STDC */
 cmd_lin( opt0, ainpc, inpv )
 char	*opt0;				/* Options specified in `main()' */
 int	*ainpc;				/* &main\argc (input and output) */
 char	**inpv;				/* main\argv (input) */
+#endif /* STDC */
 {
     return( inpv );
 }
@@ -316,7 +336,7 @@ static bool	 OPdevice	= diff;
 static bool	 OPdirect	= diff;
 static bool	 OPversion	= diff;
 
-static char	**cmd_lin(char *opt0,int *ainpc,char **inpv);
+char		**cmd_lin(char *opt0,int *ainpc,char **inpv);
 
 /* Private functions */
 static char	**add_arg(char *arg, int *acnt, char **ptrs);
@@ -344,13 +364,22 @@ int		main(int argc,char **argv);
 #endif /* TEST */
 
 char **
+#if STDC
+cmd_lin(
+char	*opt0,				/* Options specified in `main()' */
+int	*ainpc,				/* &main\argc (input and output) */
+char	**inpv				/* main\argv (input) */
+)
+#else /* NOT STDC */
 cmd_lin( opt0, ainpc, inpv )		/* returns new value for main\argv */
 char	*opt0;				/* Options specified in `main()' */
 int	*ainpc;				/* &main\argc (input and output) */
 char	**inpv;				/* main\argv (input) */
+#endif /* STDC */
 {
     int endc;	/* `endc' and `endv' will be `argc' and `argv' for main() */
-    char **endv = add_arg(0,&endc,0); /* Initialize `add_arg()' structures */
+    char **endv = add_arg((char*)NULL,&endc,(char**)NULL);
+					/* Initialize `add_arg()' structures */
     char **xtra = 0;	/* So we can free() what read_cmd_lin() may allocate */
     char *cp;
 
@@ -418,10 +447,18 @@ char	**inpv;				/* main\argv (input) */
 
 /* Builds argc,argv type lists of strings: */
 static char **
+#if STDC
+add_arg(
+  char *arg,	/* Argument to be added to the argument list */
+  int *acnt,	/* Number of arguments currently in the argument list */
+  char **ptrs	/* Array of pointers to the arguments */
+)
+#else /* NOT STDC */
 add_arg( arg, acnt, ptrs )
   char *arg;	/* Argument to be added to the argument list */
   int *acnt;	/* Number of arguments currently in the argument list */
   char **ptrs;	/* Array of pointers to the arguments */
+#endif /* STDC */
 {
 # define ARGRP 64	/* number of string pointers allocated at a time */
 	if(  !ptrs  ) { /* Initialize a new argument list: */
@@ -433,14 +470,24 @@ add_arg( arg, acnt, ptrs )
 	if(  0 == (*acnt+1) % ARGRP  ) /* Need more space for pointers */
 		ptrs = erealloc( ptrs, (*acnt+1+ARGRP) * sizeof(char *) );
 	ptrs[*acnt] = arg;
-	ptrs[++*acnt] = (char *) 0;
+	ptrs[++*acnt] = (char*)NULL;
 	return( ptrs );
 }
 
 /* Creates a logical name. */
 static uint				/* Returns a VMS condition value. */
+#if STDC
+crelnm(
+  char *table,
+  char *name, 
+  char *value
+)
+#else /* NOT STDC */
 crelnm( table, name, value )
-  char *table, *name, *value;
+  char *table;
+  char *name;
+  char *value;
+#endif /* STDC */
 {
   desc_str( tdsc, table );
   desc_str( ndsc, name );
@@ -464,8 +511,14 @@ crelnm( table, name, value )
 
 /* Same as malloc() except never returns NULL. */
 static void *
+#if STDC
+emalloc(
+  unsigned siz
+)
+#else /* NOT STDC */
 emalloc( siz )
   unsigned siz;
+#endif /* STDC */
 {
   globalvalue ss$_insfmem;	/* Insufficient dynamic memory error */
   register void *p = malloc( siz );
@@ -476,9 +529,16 @@ emalloc( siz )
 
 /* Same as realloc() except never returns NULL. */
 static void *
+#if STDC
+erealloc(
+  void *ptr,
+  unsigned siz
+)
+#else /* NOT STDC */
 erealloc( ptr, siz )
   void *ptr;
   unsigned siz;
+#endif /* STDC */
 {
   globalvalue ss$_insfmem;	/* Insufficient dynamic memory error */
   register void *p = realloc( ptr, siz );
@@ -488,8 +548,14 @@ erealloc( ptr, siz )
 }
 
 static char*
+#if STDC
+expand_logical(
+char	*logname
+)
+#else /* NOT STDC */
 expand_logical(logname)		/* return recursively expanded logical name */
 char	*logname;
+#endif /* STDC */
 {
     char	*p;
     char	*colon;
@@ -506,16 +572,28 @@ char	*logname;
 
 
 static bool	/* Returns 1 if `name' looks like a wild-carded file name. */
+#if STDC
+iswild(
+  char *name
+)
+#else /* NOT STDC */
 iswild( name )
   char *name;
+#endif /* STDC */
 {
 	return(strchr(name,'*')	 ||  strchr(name,'%')  ||  strsub(name,"..."));
 }
 
 /* Usually used to simplify argv[0]. */
 static char *
+#if STDC
+nameonly(
+  char *file
+)
+#else /* NOT STDC */
 nameonly( file )
   char *file;
+#endif /* STDC */
 {
   char *cp = file, *tp;
 #ifdef VMS
@@ -545,8 +623,14 @@ nameonly( file )
 }
 
 static char*
+#if STDC
+normalize_filename(
+char	*filename		/* with logical names expanded */
+)
+#else /* NOT STDC */
 normalize_filename(filename)	/* return lower-case copy of normalized name */
 char	*filename;		/* with logical names expanded */
+#endif /* STDC */
 {
     char	*logname;
     char	*p;
@@ -576,8 +660,14 @@ char	*filename;		/* with logical names expanded */
 
 /* Returns the next file name matching the specified wildcard. */
 static char *	/* Returns a pointer to an malloc()ed expanded filename */
+#if STDC
+nxt_wld(
+  char	*wild	/* Wildcard to be expanded. */
+)
+#else /* NOT STDC */
 nxt_wld( wild ) /* Returns 0 if all matching filenames have been returned. */
   char	*wild;	/* Wildcard to be expanded. */
+#endif /* STDC */
 {
     desc_str( wlddsc, wild );	/* VMS descriptor of wildcard string. */
     static uint cntxt = 0;	/* Context of wildcard search. */
@@ -656,9 +746,16 @@ nxt_wld( wild ) /* Returns 0 if all matching filenames have been returned. */
 /* Accepts argument beginning "{" and parses the options listed before the
  * closing "}". */
 static char **		/* Returns new value of `inpv'. */
+#if STDC
+parse_opt(
+  int *ainpc,
+  char **inpv
+)
+#else /* NOT STDC */
 parse_opt( ainpc, inpv )
   int *ainpc;
   char **inpv;
+#endif /* STDC */
 {
 	/* code to be added later */
 	return( inpv );
@@ -666,15 +763,22 @@ parse_opt( ainpc, inpv )
 
 /* Read additional command line arguments: */
 static char **
+#if STDC
+read_cmd_lin(
+  int *ainpc,
+  char **inpv
+)
+#else /* NOT STDC */
 read_cmd_lin( ainpc, inpv )
   int *ainpc;
   char **inpv;
+#endif /* STDC */
 {
   int midc;
   char **midv, line[4096], *ap, *cp, c;
 	if(  NULL == read_w_prompt( OPprompt, line, sizeof(line) )  )
 		lib$stop( vaxc$errno );
-	midv = add_arg( (char *) 0, &midc, (char *) 0 );
+	midv = add_arg( (char*)NULL, &midc, (char**)NULL );
 	while(	(*ainpc)--  )
 		midv = add_arg( *(inpv++), &midc, midv );
 	cp = strcpy(  emalloc( strlen(line)+1 ),  line	);
@@ -694,10 +798,18 @@ read_cmd_lin( ainpc, inpv )
 
 /* Prompt for a string from SYS$INPUT: */
 static char *
+#if STDC
+read_w_prompt(
+  char *prompt, /* String to prompt user with */
+  char *buff,	/* Pointer to buffer to store the string that is read */
+  int size	/* Size of *buff */
+)
+#else /* NOT STDC */
 read_w_prompt( prompt, buff, size )
   char *prompt; /* String to prompt user with */
   char *buff;	/* Pointer to buffer to store the string that is read */
   int size;	/* Size of *buff */
+#endif /* STDC */
 {
   desc_str( pdsc, prompt );
   struct descr bdsc = { size-1, dsc$k_dtype_t, dsc$k_class_s, buff };
@@ -715,6 +827,17 @@ read_w_prompt( prompt, buff, size )
 
 /* Aspects of redirection common to both ">" (and variants) and "<": */
 static char **				/* Returns new value for `inpv'. */
+#if STDC
+redir(
+  int *ainpc,
+  char **inpv,
+  FILE *fp,	/* `stdin' or `stdout' */
+  char *io,	/* "in" or "out" */
+  char *tok,	/* ", `<'" or " (`>', `>>', `>&', or `>>&')" */
+  char *lnm,	/* logical name:  "SYS$INPUT:" or "SYS$OUTPUT:" */
+  char *acc	/* file access:	 "r", "w", or "a" */
+)
+#else /* NOT STDC */
 redir( ainpc, inpv, fp, io, tok, lnm, acc )
   int *ainpc;
   char **inpv;
@@ -723,6 +846,7 @@ redir( ainpc, inpv, fp, io, tok, lnm, acc )
   char *tok;	/* ", `<'" or " (`>', `>>', `>&', or `>>&')" */
   char *lnm;	/* logical name:  "SYS$INPUT:" or "SYS$OUTPUT:" */
   char *acc;	/* file access:	 "r", "w", or "a" */
+#endif /* STDC */
 {
   uint stat = 0;	/* Assume we wouldnn't reassign `lnm'. */
 	if(  !**inpv  )		/* Not ">file" / "<file", must be... */
@@ -764,9 +888,16 @@ redir( ainpc, inpv, fp, io, tok, lnm, acc )
 
 /* Redirects `stdin': */
 static char **
+#if STDC
+redirin(
+  int *ainpc,
+  char **inpv
+)
+#else /* NOT STDC */
 redirin( ainpc, inpv )
   int *ainpc;
   char **inpv;
+#endif /* STDC */
 {
 	++*inpv;	/* Skip over the '<'. */
 	return(redir( ainpc, inpv, stdin, "in", ", `<'", "SYS$INPUT:", "r" ));
@@ -774,9 +905,16 @@ redirin( ainpc, inpv )
 
 /* Redirects `stdout': */
 static char **
+#if STDC
+redirout(
+  int *ainpc,
+  char **inpv
+)
+#else /* NOT STDC */
 redirout( ainpc, inpv )
   int *ainpc;
   char **inpv;
+#endif /* STDC */
 {
   bool err = 0;		/* Assume not ">&" nor ">>&". */
   char *acc = "w";	/* Assume ">" (write) not ">>" (append). */
@@ -801,8 +939,14 @@ redirout( ainpc, inpv )
 /* Signals any non-boring condition values so that error/warning messages
  * will be displayed. */
 static void
+#if STDC
+sigvms(
+  uint stat
+)
+#else /* NOT STDC */
 sigvms( stat )
   uint stat;
+#endif /* STDC */
 {
   extern void lib$signal();
 	if(  ( stat & 0xffff ) == 1 )
@@ -813,8 +957,16 @@ sigvms( stat )
 /* Returns the position of a substring within a string.	 Should be replaced by
  * strstr() when DEC provides one. */
 static char *
+#if STDC
+strsub(
+  char *str,
+  char *sub
+)
+#else /* NOT STDC */
 strsub( str, sub )
-  char *str, *sub;
+  char *str;
+  char *sub;
+#endif /* STDC */
 {
   register char *fp = sub;	/* Points to character we hope to Find next */
   char *sp = strchr(str,*fp);	/* Points to current Starting character */
@@ -834,8 +986,14 @@ strsub( str, sub )
 /* Displays a string to `stdout', making all control and meta characters
  * printable unambigously. */
 static void
+#if STDC
+dump(
+  char *str
+)
+#else /* NOT STDC */
 dump( str )
   char *str;
+#endif /* STDC */
 {
 # define META '`'	/* Show 'a'+'\200' as "`a" */
 # define CTRL '^'	/* Show '\001' as "^A" */
@@ -869,9 +1027,16 @@ dump( str )
 }
 
 int
+#if STDC
+main(
+  int argc,
+  char **argv
+)
+#else /* NOT STDC */
 main( argc, argv )
   int argc;
   char **argv;
+#endif /* STDC */
 {
     int cnt;
     extern char **cmd_lin();
